FSharp.Data.Fred Namespace
Functionality related to accessing the FRED database. Short for Federal Reserve Economic Data, FRED is an online database consisting of hundreds of thousands of economic data time series from scores of national, international, public, and private sources. See https://fred.stlouisfed.org/.
| Type/Module | Description |
|
Represents a type for accessing the Fred API. You must provide an api key. |
|
|
Contains types for specifying search query parameters. |
|
|
|
|
|
A data series. |
FSharp.Data.Fred